@@ -1,6 +1,6 @@
 from django.db import models
 from edc_model.models import BaseUuidModel, HistoricalRecords
-from edc_randomization.models import RandomizationListModelMixin
+from edc_randomization.model_mixins import RandomizationListModelMixin
 
 
 class PiiModel(models.Model):
